@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2005 Zope Corporation and Contributors.
+# Copyright (c) 2005-2008 Zope Corporation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -14,13 +14,12 @@
 """Zope 3 Monitor Server
 """
 
-import errno, logging, os, re, time, traceback, socket
+import os, re, time
 
 import ZODB.ActivityMonitor
 import ZODB.interfaces
-
+import zc.monitor
 import zope.component
-import zope.component.interfaces
 import zope.interface
 import zope.publisher.browser
 import zope.publisher.interfaces.browser
@@ -30,91 +29,6 @@ import zope.app.appsetup.interfaces
 import zope.app.appsetup.product
 import zope.app.publication.interfaces
 
-import zc.ngi.adapters
-
-INTERACTIVE_MARKER = object()
-QUIT_MARKER = object()
-
-class Server:
-
-    def __init__(self, connection):
-        connection = zc.ngi.adapters.Lines(connection)
-        self.connection = connection
-        connection.setHandler(self)
-        self.mode = QUIT_MARKER
-
-    def handle_input(self, connection, data):
-        args = data.strip().split()
-        if not args:
-            return
-        command_name = args.pop(0)
-        command = zope.component.queryUtility(
-            zc.z3monitor.interfaces.IZ3MonitorPlugin,
-            command_name)
-        if command is None:
-            connection.write(
-                'Invalid command %r\nTry "help".\n' % command_name)
-        else:
-            try:
-                res = command(connection, *args)
-            except Exception, v:
-                traceback.print_exc(100, connection)
-                print >> connection, "%s: %s\n" % (v.__class__.__name__, v)
-            if res is INTERACTIVE_MARKER:
-                self.mode = res
-            elif res is QUIT_MARKER:
-                self.mode = res
-
-        if self.mode is QUIT_MARKER:
-            connection.write(zc.ngi.END_OF_DATA)
-
-    def handle_close(self, connection, reason):
-        pass                            # Don't care
-
-
-def interactive(connection):
-    """Turn on monitor's interactive mode
-    
-    Normally, the monitor releases the connection after a single command.
-    By entering the interactive mode, the monitor will not end the connection
-    until you enter the "quit" command.
-    """
-    connection.write('Interactive mode on.  Use "quit" To exit.\n')
-    return INTERACTIVE_MARKER
-
-def quit(connection):
-    """Quit the monitor
-    
-    This is only really useful in interactive mode (see the "interactive"
-    command).
-    """
-    connection.write('Goodbye.\n')
-    return QUIT_MARKER
-
-
-def help(connection, command_name=None):
-    """Get help about server commands
-
-    By default, a list of commands and summaries is printed.  Provide
-    a command name to get detailed documentation for a command.
-    """
-    if command_name is None:
-        connection.write(str(
-            "Supported commands:\n  "
-            + '\n  '.join(sorted(
-                "%s -- %s" % (name, (u.__doc__ or '?').split('\n', 1)[0])
-                for (name, u) in
-                zope.component.getUtilitiesFor(
-                    zc.z3monitor.interfaces.IZ3MonitorPlugin)))
-            + '\n'))
-    else:
-        command = zope.component.getUtility(
-            zc.z3monitor.interfaces.IZ3MonitorPlugin,
-            command_name)
-        connection.write("Help for %s:\n\n%s\n"
-                         % (command_name, command.__doc__)
-                         )
-
 opened_time_search = re.compile('[(](\d+[.]\d*)s[)]').search
 
 def monitor(connection, long=100, database=''):
@@ -258,19 +172,7 @@ def initialize(opened_event):
             db.setActivityMonitor(ZODB.ActivityMonitor.ActivityMonitor())
 
     port = int(config['port'])
-    import zc.ngi.async
-    try:
-        zc.ngi.async.listener(('', port), Server)
-    except socket.error, e:
-        if e.args[0] == errno.EADDRINUSE:
-            # this might be a zopectl debug.  Don't kill the process just
-            # because somebody else has our port.
-            logging.warning(
-                'unable to start z3monitor server because port %d is in use.',
-                port)
-        else:
-            raise
-        
+    zc.monitor.start(int(config['port']))
 
 @zope.component.adapter(
     zope.traversing.interfaces.IContainmentRoot,
